==> libpappsomspp_0.7.4.orig.tar.gz: libpappsomspp-0.7.4/src/pappsomspp/vendors/tims/xicextractor/timsxicextractorinterface.cpp <==
/**
 * \file pappsomspp/vendors/tims/xicextractor/timsxicextractorinterface.cpp
 * \date 21/09/2019
 * \author Olivier Langella
 * \brief minimum functions to extract XICs from Tims Data
 */

/*******************************************************************************
 * Copyright (c) 2019 Olivier Langella <Olivier.Langella@u-psud.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#include "timsxicextractorinterface.h"

using namespace pappso;

TimsXicExtractorInterface::TimsXicExtractorInterface(TimsData *mp_tims_data)
  : mp_timsData(mp_tims_data)
{
}

TimsXicExtractorInterface::~TimsXicExtractorInterface()
{
}

void
TimsXicExtractorInterface::setXicExtractMethod(XicExtractMethod method)
{
  m_xicExtractMethod = method;
}

==> libpappsomspp_0.7.14.orig.tar.gz: libpappsomspp-0.7.14/src/pappsomspp/vendors/tims/xicextractor/timsxicextractorinterface.cpp <==
/**
 * \file pappsomspp/vendors/tims/xicextractor/timsxicextractorinterface.cpp
 * \date 21/09/2019
 * \author Olivier Langella
 * \brief minimum functions to extract XICs from Tims Data
 */

/*******************************************************************************
 * Copyright (c) 2019 Olivier Langella <Olivier.Langella@u-psud.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#include "timsxicextractorinterface.h"

using namespace pappso;

TimsXicExtractorInterface::TimsXicExtractorInterface(
  const TimsData *mp_tims_data)
  : mp_timsData(mp_tims_data)
{
}

TimsXicExtractorInterface::~TimsXicExtractorInterface()
{
}

void
TimsXicExtractorInterface::setXicExtractMethod(XicExtractMethod method)
{
  m_xicExtractMethod = method;
}
